@@ -15,16 +15,15 @@ Node * new(int child_count)
   if ((child_count < 1) || (child_count > MAX_LEVEL))
     croak("child_count out of bounds: must be between [1..%d]", MAX_LEVEL);
 
-#if USE_MALLOC
   n = malloc((size_t) NODESIZE(child_count));
   if (n == NULL)
     croak("unable to a allocate memory");
-#else
-  Newc(1, n, NODESIZE(child_count), char, Node);
-#endif
 
   n->child_count  = child_count;
 
+  while (child_count--)
+    n->next[child_count] = &PL_sv_undef;
+
   n->key   = &PL_sv_undef;
   n->value = &PL_sv_undef;
 
@@ -33,14 +32,15 @@ Node * new(int child_count)
 
 void DESTROY(Node* n)
 {
+  int child_count = n->child_count;
+
   SvREFCNT_dec(n->key);
   SvREFCNT_dec(n->value);
 
-#if USE_MALLOC
+  while (child_count--)
+    SvREFCNT_dec(n->next[child_count]);
+
   free(n);
-#else
-  Safefree(n);
-#endif
 }
 
 int child_count(Node * n)
@@ -85,32 +85,14 @@ void set_key(Node *n, SV* k)
   }
 }
 
-void force_set_key(Node *n, SV* k)
-{
-  if (SvOK(n->key)) {
-    warn("key is already set");
-  }
-  n->key = newRV_inc(k);
-}
-
 SV* get_key(Node *n)
 {
-  if (SvOK(n->key)) {
-    return SvREFCNT_inc(SvRV(n->key));
-  }
-  else {
-    return &PL_sv_undef;
-  }
+  return SvREFCNT_inc(SvRV(n->key));
 }
 
 I32 key_cmp(Node* n, SV* k)
 {
-  if (SvOK(n->key)) {
     return sv_cmp(SvRV(n->key), k);
-  }
-  else {
-    return -1;
-  }
 }
 
 void set_value(Node *n, SV* v)
@@ -120,12 +102,7 @@ void set_value(Node *n, SV* v)
 
 SV* get_value(Node *n)
 {
-  if (SvOK(n->key)) {
-    return SvREFCNT_inc(SvRV(n->value));
-  }
-  else {
-    return &PL_sv_undef;
-  }
+  return SvREFCNT_inc(SvRV(n->value));
 }
 
 int _allocated(Node* n)
