@@ -1,3 +1,5 @@
+
+
 #include "perl.h"
 
 #ifndef MAX_LEVEL
@@ -7,14 +9,10 @@
 
 #define NODESIZE(N) sizeof(Node) + (sizeof(SV*) * (N+1))
 
-#define SV2NODE(S) INT2PTR(Node*, SvIV(SvRV(S)))
-
-#define IV2NODE(S) INT2PTR(Node*, S)
-
 typedef struct {
   SV*   key;
   SV*   value;
-  int   child_count;
+  int	child_count;
   SV*   next[]; 
 } Node;
 
@@ -28,7 +26,6 @@ SV* get_child_or_undef(Node * n, int index);
 void set_child(Node* n, int index, SV* t);
 
 void set_key(Node *n, SV* k);
-void force_set_key(Node *n, SV* k);
 SV* get_key(Node *n);
 I32 key_cmp(Node* n, SV* k);
 
@@ -37,3 +34,4 @@ SV* get_value(Node *n);
 
 int _allocated(Node* n);
 
+
